@@ -1,8 +1,8 @@
 #!/usr/bin/env perl
 
 package Git::Hooks::CheckAcls;
-# ABSTRACT: Git::Hooks plugin for branch/tag access control.
-$Git::Hooks::CheckAcls::VERSION = '1.6.9';
+# ABSTRACT: Git::Hooks plugin for branch/tag access control
+$Git::Hooks::CheckAcls::VERSION = '1.6.10';
 use 5.010;
 use utf8;
 use strict;
@@ -122,11 +122,11 @@ __END__
 
 =head1 NAME
 
-Git::Hooks::CheckAcls - Git::Hooks plugin for branch/tag access control.
+Git::Hooks::CheckAcls - Git::Hooks plugin for branch/tag access control
 
 =head1 VERSION
 
-version 1.6.9
+version 1.6.10
 
 =head1 DESCRIPTION
 
@@ -239,8 +239,8 @@ This is useful, for instance, if you want developers to be restricted
 in what they can do to official branches but to have complete control
 with their own branch namespace.
 
-    git config CheckAcls.acl '^. CRUD ^refs/heads/{USER}/'
-    git config CheckAcls.acl '^. U    ^refs/heads'
+    git config githooks.CheckAcls.acl '^. CRUD ^refs/heads/{USER}/'
+    git config githooks.CheckAcls.acl '^. U    ^refs/heads'
 
 In this example, every user (^.) has complete control (CRUD) to the
 branches below "refs/heads/{USER}". Supposing the environment variable
