@@ -1,8 +1,8 @@
 #!/usr/bin/env perl
 
 package Git::Hooks::CheckJira;
-# ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages.
-$Git::Hooks::CheckJira::VERSION = '1.6.9';
+# ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
+$Git::Hooks::CheckJira::VERSION = '1.6.10';
 use 5.010;
 use utf8;
 use strict;
@@ -11,7 +11,6 @@ use Git::Hooks qw/:DEFAULT :utils/;
 use Path::Tiny;
 use Data::Util qw(:check);
 use List::MoreUtils qw/uniq/;
-use JIRA::REST;
 
 my $PKG = __PACKAGE__;
 (my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
@@ -66,6 +65,11 @@ sub _jira {
 
     # Connect to JIRA if not yet connected
     unless (exists $cache->{jira}) {
+        unless (eval { require JIRA::REST; }) {
+            $git->error($PKG, "Please, install Perl module JIRA::REST to use the CheckJira plugin", $@);
+            return;
+        }
+
         my %jira;
         for my $option (qw/jiraurl jirauser jirapass/) {
             $jira{$option} = $git->get_config($CFG => $option)
@@ -367,11 +371,11 @@ __END__
 
 =head1 NAME
 
-Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues in commit messages.
+Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues in commit messages
 
 =head1 VERSION
 
-version 1.6.9
+version 1.6.10
 
 =head1 DESCRIPTION
 
