@@ -1,8 +1,8 @@
 #!/usr/bin/env perl
 
 package Git::Hooks::CheckLog;
-# ABSTRACT: Git::Hooks plugin to enforce commit log policies.
-$Git::Hooks::CheckLog::VERSION = '1.6.9';
+# ABSTRACT: Git::Hooks plugin to enforce commit log policies
+$Git::Hooks::CheckLog::VERSION = '1.6.10';
 use 5.010;
 use utf8;
 use strict;
@@ -48,7 +48,7 @@ sub _spell_checker {
 
     unless (state $tried_to_check) {
         unless (eval { require Text::SpellChecker; }) {
-            $git->error($PKG, "could not require Text::SpellChecker module to spell messages", $@);
+            $git->error($PKG, "Please, install Perl module Text::SpellChecker to spell messages", $@);
             return;
         }
 
@@ -273,11 +273,11 @@ __END__
 
 =head1 NAME
 
-Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies.
+Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 =head1 VERSION
 
-version 1.6.9
+version 1.6.10
 
 =head1 DESCRIPTION
 
